
--[[	
												GENERIC INTERFACE ELEMENTS TABLE

QUANTITY		TYPE							NAME		 DEVICE		  BUTTON			   SEND ID		FORMAT			VALUES
																				
	199		Network Values					NetworkValue 				   		   			   1 to 199		%0.3f		numeric
	199		FlagValues						FlagValue 					 					1001 to 1199	%1d			0,1
	199		PushButtons 					PB 					1		3001 to 3199		2001 to 2199	%0.1f		0.0,1.0
	249		Toggle switches 				TSwitch 			2		3001 to 3249		3001 to 3249  	%1d			1,0
	249		Toggles witches B				TSwitch_B 			12		3001 to 3249		4001 to 4249  	%1d			1,-1
	99		Three way switches A			3WSwitch_A 			3		3001 to 3099		5001 to 5099 	%1d			1,0,-1
	99		Three way switches B			3WSwitch_B 			3		3101 to 3199		5101 to 5199 	%0.1f		0.0,0.1,0.2
	99		Three way switches C			3WSwitch_C 			3		3201 to 3299		5201 to 5299 	%0.1f		0,0.5,1
	99		Axis A							Axis_A 				4		3001 to 3099		6001 to 6099 	%0.2f		0.1
	99		Axis B 							Axis_B 				4		3101 to 3199		6101 to 6199 	%0.2f		0.05
	49		Multiposition Switch 6 pos 		Multi6PosSwitch 	5		3001 to 3049		7001 to 7049  	%0.1f		0.0,0.1,0.2,0.3,0.4,0.5
	49		Multiposition Switch 11 pos		Multi11PosSwitch	5		3051 to 3099	 	7051 to 7099  	%0.1f		0.0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,1.0
	20		Multiposition Switch 21	pos		Multi21PosSwitch	5		3101 to 3120	 	7101 to 7120  	%0.2f		0.0,0.05,0.1,0.15,0.2,0.25,0.3,0.35,0.4,0.45,0.5,0.55,0.6,0.65,0.7,0.75,0.8,0.85,0.9,0.95,1.0
	49		Rocker A						Rocker_A 			7		3001 to 3049		8001 to 8049 	%1d			ABCC
	49		Rocker B						Rocker_B 			8		3050 to 3099		8050 to 8099 	%1d			ABAB
	49		Rocker C						Rocker_C 			10		3101 to 3149		8101 to 8149 	%1d			AABB
	49		Rotator Encoder A 				RotEncoder_A 		9		3001 to 3049		9001 to 9049 	%0.2f		0.1
	49		Rotator Encoder B 				RotEncoder_B 		9		3051 to 3099		9051 to 9099 	%0.2f		0.05
	99		Indicator Push Button			Ind_PButton 		11		3001 to 3099	   10001 to 10099	%0.1f		0.0,0.1 / 0,1




Usefull functions:

Helios_Util.ValueConvert(value,{0, 0.37, 1},{-1, 0.0, 1.0}) convert the value from one input scale to output scale, Used in non lineal instruments values 
Helios_Util.Convert_Lamp (value)    convert value to 1 if value is bigger than 0.1, Usually used for lamps values
Helios_Util.Split(string,",")   split a string into several string using the character as divider
Helios_Util.GetListIndicator(value)   return the strings on the indicator
]]--




Helios_NewAirplane = {} -- replace the name of this array with the name of your airplane, for example: Helios_F-5E

Helios_NewAirplane.Name = "DCSinternalAirplaneName" -- this is the internal name of the airplane in DCS, you need to found it! for the F-5E for example is "F-5E-3"
											   -- You can use several names separated by ; in case you want to use the profile for several models of the airplane, for example "L-39C;L-39ZA" 
Helios_NewAirplane.FlamingCliffsAircraft = false

Helios_NewAirplane.ExportArguments = {}


----------------------------------------------------------------------- SEND HIGHT IMPORTANCE DATA TO HELIOS
--- usually to send instruments data and lamps

function Helios_NewAirplane.HighImportance(data)

	local MainPanel = GetDevice(0)

	
	-- Pilot console instruments
		--Helios_Udp.Send("1", string.format("%0.3f",  MainPanel:get_argument_value(7) ) )
	



	Helios_Udp.Flush()
end

----------------------------------------------------------------------- SEND LOW IMPORTANCE DATA TO HELIOS
---- usually to send switches, levers, buttons etc

function Helios_NewAirplane.LowImportance(MainPanel)

	-- switches
		--Helios_Udp.Send("3001", string.format("%1d", MainPanel:get_argument_value(497) ) ) -- Standby Generator Switch, ON/OFF >> TSwitch_1

	
				
	Helios_Udp.Flush()
end


------------------------------------------------------------------------ SEND OUTPUT VALUES TO DCS TABLE
--  Format:
--  Helios_NewAirplane.ExportArguments["GENERIC DEVICE,GENERIC BUTTON"] ="AIRPLANE DEVICE, AIRPLANE BUTTON,MULTIPLIER"
--  arguments with multiplier >100  are special conversion cases, and are computed in different way, you can see the convertion data in the function bellow


	--Helios_NewAirplane.ExportArguments["1,3001"] ="1, 3022,1" --  CB Group 1 ON    882















------------------------------------------------------------------------ PROCESS INPUT DATA
function Helios_NewAirplane.ProcessInput(data)
    local lCommand, lCommandArgs, lDevice, lArgument, lLastValue
    local sIndex, lConvDevice
	local valor_axis, absoluto, min_clamp
	
	lCommand = string.sub(data,1,1)
	
	if lCommand == "R" then
		Helios_Udp.ResetChangeValues()
	end

	if (lCommand == "C") then
		lCommandArgs = Helios_Util.Split(string.sub(data,2),",")
		sIndex = lCommandArgs[1]..","..lCommandArgs[2]
		lConvDevice = Helios_NewAirplane.ExportArguments[sIndex] 	
		lArgument = Helios_Util.Split(string.sub(lConvDevice,1),",")
		min_clamp = 0
		max_clamp = 1
		
				
		lDevice = GetDevice(lArgument[1])    -- data conversions between switches extended and the NewAirplane
		if type(lDevice) == "table" then
		
			if lArgument[3]=="100" then   -- convert 0.2 0.1 0.0 to 1 0 -1
			 local temporal= lCommandArgs[3]
				lCommandArgs[3] = ((temporal)*10)-1
				lArgument[3] = 1
			end
			if lArgument[3]=="101" then   -- convert 1 0.5 0.0 to 1 0 -1
			 local temporal= lCommandArgs[3]
				lCommandArgs[3] = (temporal*2)-1
				lArgument[3] = 1
			end
			if lArgument[3]=="102" then   -- convert 1 0 to 1 -1
			 local temporal= lCommandArgs[3]
				lCommandArgs[3] = (temporal*2)-1
				lArgument[3] = 1
			end
			if lArgument[3]=="103" then   -- convert 1 0 -1 to 1 0.5 0.0
			 local temporal= lCommandArgs[3]
				lCommandArgs[3] = (temporal+1)/2
				lArgument[3] = 1
			end
			if lArgument[3]=="104" then   -- convert 0.2 0.1 0.0 to 0.2 0.1 0.3
			 --local temporal= lCommandArgs[3]

				if lCommandArgs[3] <= "0.05" then
				 lCommandArgs[3] = 0.3
				end
				lArgument[3] = 1
			end
			if lArgument[3]=="105" then   -- convert 0.0 0.1 0.2 0.3 0.4  to -0.1 0.0 0.1 0.2 0.3
			 local temporal= lCommandArgs[3]
				lCommandArgs[3] = temporal - 0.1
				lArgument[3] = 1
				
			end
			if lArgument[3]=="106" then   -- convert 0.2 0.1 0.0  to 1.0 0.5 0.0
			 local temporal= lCommandArgs[3]
				lCommandArgs[3] = temporal*5
				lArgument[3] = 1
				
			end
			
			lDevice:performClickableAction(lArgument[2],lCommandArgs[3]*lArgument[3])
		end
	end
end










